@@ -7,7 +7,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -25,6 +25,6 @@
 # *
 # **************************************************************************
 
-from protocol_base import ImagicProtocol
-from protocol_msa import ImagicProtMSA
-from protocol_msa_classify import ImagicProtMSAClassify
+from .protocol_base import ImagicProtocol
+from .protocol_msa import ImagicProtMSA
+from .protocol_msa_classify import ImagicProtMSAClassify
